@@ -1,4 +1,4 @@
-from yq.__init__ import cli
+from . import cli
 
 if __name__ == "__main__":
     cli()
